@@ -1,17 +1,15 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-
 extensions = [
     'sphinx.ext.autodoc',
     'jaraco.packaging.sphinx',
 ]
 
 master_doc = "index"
+html_theme = "furo"
 
 # Link dates and other references in the changelog
 extensions += ['rst.linker']
 link_files = {
-    '../CHANGES.rst': dict(
+    '../NEWS.rst': dict(
         using=dict(GH='https://github.com'),
         replace=[
             dict(
@@ -32,6 +30,18 @@ link_files = {
 
 # Be strict about any broken references
 nitpicky = True
+nitpick_ignore = [
+    ('py:class', 'Self'),
+    ('py:class', '_T'),
+    ('py:class', '_U'),
+    ('py:obj', 'jaraco.classes.properties._T'),
+    ('py:obj', 'jaraco.classes.properties._U'),
+    ('py:class', '_ClassPropertyAttribute'),
+    ('py:class', '_GetterCallable'),
+    ('py:class', '_GetterClassMethod'),
+    ('py:class', '_SetterCallable'),
+    ('py:class', '_SetterClassMethod'),
+]
 
 # Include Python intersphinx mapping to prevent failures
 # jaraco/skeleton#51
